==> druid-server-0.22.1-sources.jar: org/apache/druid/segment/loading/SegmentLocalCacheLoader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.segment.loading;

import com.fasterxml.jackson.databind.ObjectMapper;
import org.apache.druid.guice.annotations.Json;
import org.apache.druid.segment.IndexIO;
import org.apache.druid.segment.ReferenceCountingSegment;
import org.apache.druid.segment.Segment;
import org.apache.druid.segment.SegmentLazyLoadFailCallback;
import org.apache.druid.timeline.DataSegment;

import javax.inject.Inject;

import java.io.File;
import java.io.IOException;

public class SegmentLocalCacheLoader implements SegmentLoader
{
  private final SegmentCacheManager cacheManager;
  private final IndexIO indexIO;
  private final ObjectMapper jsonMapper;

  @Inject
  public SegmentLocalCacheLoader(SegmentCacheManager cacheManager, IndexIO indexIO, @Json ObjectMapper mapper)
  {
    this.cacheManager = cacheManager;
    this.indexIO = indexIO;
    this.jsonMapper = mapper;
  }

  @Override
  public ReferenceCountingSegment getSegment(DataSegment segment, boolean lazy, SegmentLazyLoadFailCallback loadFailed) throws SegmentLoadingException
  {
    final File segmentFiles = cacheManager.getSegmentFiles(segment);
    File factoryJson = new File(segmentFiles, "factory.json");
    final SegmentizerFactory factory;

    if (factoryJson.exists()) {
      try {
        factory = jsonMapper.readValue(factoryJson, SegmentizerFactory.class);
      }
      catch (IOException e) {
        throw new SegmentLoadingException(e, "%s", e.getMessage());
      }
    } else {
      factory = new MMappedQueryableSegmentizerFactory(indexIO);
    }

    Segment segmentObject = factory.factorize(segment, segmentFiles, lazy, loadFailed);
    return ReferenceCountingSegment.wrapSegment(segmentObject, segment.getShardSpec());
  }

  @Override
  public void cleanup(DataSegment segment)
  {
    cacheManager.cleanup(segment);
  }
}

==> druid-server-24.0.2-sources.jar: org/apache/druid/segment/loading/SegmentLocalCacheLoader.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.segment.loading;

import com.fasterxml.jackson.databind.ObjectMapper;
import org.apache.druid.guice.annotations.Json;
import org.apache.druid.java.util.emitter.EmittingLogger;
import org.apache.druid.segment.IndexIO;
import org.apache.druid.segment.ReferenceCountingSegment;
import org.apache.druid.segment.Segment;
import org.apache.druid.segment.SegmentLazyLoadFailCallback;
import org.apache.druid.timeline.DataSegment;

import javax.inject.Inject;
import java.io.File;
import java.io.IOException;
import java.util.concurrent.ExecutorService;

public class SegmentLocalCacheLoader implements SegmentLoader
{
  private static final EmittingLogger log = new EmittingLogger(SegmentLocalCacheLoader.class);

  private final SegmentCacheManager cacheManager;
  private final IndexIO indexIO;
  private final ObjectMapper jsonMapper;

  @Inject
  public SegmentLocalCacheLoader(SegmentCacheManager cacheManager, IndexIO indexIO, @Json ObjectMapper mapper)
  {
    this.cacheManager = cacheManager;
    this.indexIO = indexIO;
    this.jsonMapper = mapper;
  }

  @Override
  public ReferenceCountingSegment getSegment(DataSegment segment, boolean lazy, SegmentLazyLoadFailCallback loadFailed)
      throws SegmentLoadingException
  {
    final File segmentFiles = cacheManager.getSegmentFiles(segment);
    File factoryJson = new File(segmentFiles, "factory.json");
    final SegmentizerFactory factory;

    if (factoryJson.exists()) {
      try {
        factory = jsonMapper.readValue(factoryJson, SegmentizerFactory.class);
      }
      catch (IOException e) {
        throw new SegmentLoadingException(e, "%s", e.getMessage());
      }
    } else {
      factory = new MMappedQueryableSegmentizerFactory(indexIO);
    }

    Segment segmentObject = factory.factorize(segment, segmentFiles, lazy, loadFailed);

    return ReferenceCountingSegment.wrapSegment(segmentObject, segment.getShardSpec());
  }

  @Override
  public void cleanup(DataSegment segment)
  {
    cacheManager.cleanup(segment);
  }

  @Override
  public void loadSegmentIntoPageCache(DataSegment segment, ExecutorService exec)
  {
    cacheManager.loadSegmentIntoPageCache(segment, exec);
  }
}
